@@ -16,8 +16,9 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, MutableMapping, MutableSequence, Optional, Sequence, Tuple, Type, Union, cast
+
+from oceanbolt.com.drydock_v3 import gapic_version as package_version
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -52,7 +53,7 @@ class DrydockServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = DrydockServiceGrpcAsyncIOTransport
 
     def get_transport_class(cls,
-            label: str = None,
+            label: Optional[str] = None,
         ) -> Type[DrydockServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -227,7 +228,7 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -274,8 +275,8 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
 
     def __init__(self, *,
             credentials: Optional[ga_credentials.Credentials] = None,
-            transport: Union[str, DrydockServiceTransport, None] = None,
-            client_options: Optional[client_options_lib.ClientOptions] = None,
+            transport: Optional[Union[str, DrydockServiceTransport]] = None,
+            client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
             client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
             ) -> None:
         """Instantiates the drydock service client.
@@ -289,7 +290,7 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
             transport (Union[str, DrydockServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -319,6 +320,7 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(client_options)
 
@@ -360,10 +362,10 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
             )
 
     def get_dry_dock_stays(self,
-            request: Union[service.GetDryDockStaysRequest, dict] = None,
+            request: Optional[Union[service.GetDryDockStaysRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetDryDockStaysResponse:
         r"""GetDryDockStays retrives individual historical dry
@@ -371,6 +373,13 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import drydock_v3
 
             def sample_get_dry_dock_stays():
@@ -424,10 +433,10 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
         return response
 
     def get_dry_dock_timeseries(self,
-            request: Union[service.GetDryDockRequest, dict] = None,
+            request: Optional[Union[service.GetDryDockRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.DryDockResponse:
         r"""GetDryDockTimeseries retrieves dry dock timeseries data for a
@@ -435,6 +444,13 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import drydock_v3
 
             def sample_get_dry_dock_timeseries():
@@ -488,10 +504,10 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
         return response
 
     def get_dry_dock_web(self,
-            request: Union[service.GetDryDockRequest, dict] = None,
+            request: Optional[Union[service.GetDryDockRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.DryDockResponse:
         r"""GetDryDockWeb retrieves current and live dry dock data for a
@@ -499,6 +515,13 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import drydock_v3
 
             def sample_get_dry_dock_web():
@@ -552,10 +575,10 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
         return response
 
     def get_dry_dock_vessels(self,
-            request: Union[service.GetDryDockRequest, dict] = None,
+            request: Optional[Union[service.GetDryDockRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.DryDockResponse:
         r"""GetDryDockVessels retrieves list of currently active dry dock
@@ -563,6 +586,13 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import drydock_v3
 
             def sample_get_dry_dock_vessels():
@@ -615,7 +645,7 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "DrydockServiceClient":
         return self
 
     def __exit__(self, type, value, traceback):
@@ -633,14 +663,8 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
 
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "oceanbolt-com-drydock",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(gapic_version=package_version.__version__)
 
 
 __all__ = (
