@@ -16,17 +16,20 @@
 from .service import (
     Commodity,
     Country,
-    EmptyParams,
+    ListCommoditiesRequest,
     ListCommoditiesResponse,
     ListCountriesRequest,
     ListCountriesResponse,
+    ListPortsRequest,
     ListPortsResponse,
     ListRegionsRequest,
     ListRegionsResponse,
     ListRegionsWithPolygonResponse,
+    ListSegmentsRequest,
     ListSegmentsResponse,
     ListTonnageZonesResponse,
     ListTonnageZonesWithPolygonsResponse,
+    ListZonesRequest,
     Polygon,
     Port,
     Region,
@@ -43,17 +46,20 @@ from .service import (
 __all__ = (
     'Commodity',
     'Country',
-    'EmptyParams',
+    'ListCommoditiesRequest',
     'ListCommoditiesResponse',
     'ListCountriesRequest',
     'ListCountriesResponse',
+    'ListPortsRequest',
     'ListPortsResponse',
     'ListRegionsRequest',
     'ListRegionsResponse',
     'ListRegionsWithPolygonResponse',
+    'ListSegmentsRequest',
     'ListSegmentsResponse',
     'ListTonnageZonesResponse',
     'ListTonnageZonesWithPolygonsResponse',
+    'ListZonesRequest',
     'Polygon',
     'Port',
     'Region',
