@@ -13,6 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from oceanbolt.com.fleetmanagement_v3 import gapic_version as package_version
+
+__version__ = package_version.__version__
+
 
 from .services.fleet_management_service import FleetManagementServiceClient
 from .services.fleet_management_service import FleetManagementServiceAsyncClient
@@ -31,6 +35,7 @@ from .types.service import GetFleetListRequest
 from .types.service import GetFleetLiveMapRequest
 from .types.service import GetFleetLiveMapResponse
 from .types.service import GetFleetRequest
+from .types.service import GetVesselRequest
 from .types.service import ListVesselsRequest
 from .types.service import ListVesselsWithStatusRequest
 from .types.service import RenameFleetRequest
@@ -60,6 +65,7 @@ __all__ = (
 'GetFleetLiveMapRequest',
 'GetFleetLiveMapResponse',
 'GetFleetRequest',
+'GetVesselRequest',
 'ListVesselsRequest',
 'ListVesselsWithStatusRequest',
 'RenameFleetRequest',
