@@ -16,8 +16,9 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, MutableMapping, MutableSequence, Optional, Sequence, Tuple, Type, Union
+
+from oceanbolt.com.fleetmanagement_v3 import gapic_version as package_version
 
 from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
@@ -104,7 +105,7 @@ class FleetManagementServiceAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -136,9 +137,9 @@ class FleetManagementServiceAsyncClient:
     get_transport_class = functools.partial(type(FleetManagementServiceClient).get_transport_class, type(FleetManagementServiceClient))
 
     def __init__(self, *,
-            credentials: ga_credentials.Credentials = None,
+            credentials: Optional[ga_credentials.Credentials] = None,
             transport: Union[str, FleetManagementServiceTransport] = "grpc_asyncio",
-            client_options: ClientOptions = None,
+            client_options: Optional[ClientOptions] = None,
             client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
             ) -> None:
         """Instantiates the fleet management service client.
@@ -182,10 +183,10 @@ class FleetManagementServiceAsyncClient:
         )
 
     async def list_fleets(self,
-            request: Union[service.EmptyParams, dict] = None,
+            request: Optional[Union[service.EmptyParams, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Fleets:
         r"""Lists Fleets for the current user (or fleets that are
@@ -193,6 +194,13 @@ class FleetManagementServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import fleetmanagement_v3
 
             async def sample_list_fleets():
@@ -210,7 +218,7 @@ class FleetManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.fleetmanagement_v3.types.EmptyParams, dict]):
+            request (Optional[Union[oceanbolt.com.fleetmanagement_v3.types.EmptyParams, dict]]):
                 The request object. Empty request object
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -245,16 +253,23 @@ class FleetManagementServiceAsyncClient:
         return response
 
     async def create_fleet(self,
-            request: Union[service.CreateFleetRequest, dict] = None,
+            request: Optional[Union[service.CreateFleetRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Fleet:
         r"""Creates a new Fleet for the current user.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import fleetmanagement_v3
 
             async def sample_create_fleet():
@@ -272,7 +287,7 @@ class FleetManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.fleetmanagement_v3.types.CreateFleetRequest, dict]):
+            request (Optional[Union[oceanbolt.com.fleetmanagement_v3.types.CreateFleetRequest, dict]]):
                 The request object. Request object for creating a Fleet
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -307,16 +322,23 @@ class FleetManagementServiceAsyncClient:
         return response
 
     async def delete_fleet(self,
-            request: Union[service.DeleteFleetRequest, dict] = None,
+            request: Optional[Union[service.DeleteFleetRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.EmptyResponse:
         r"""Deletes a Fleet for the current user.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import fleetmanagement_v3
 
             async def sample_delete_fleet():
@@ -334,7 +356,7 @@ class FleetManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.fleetmanagement_v3.types.DeleteFleetRequest, dict]):
+            request (Optional[Union[oceanbolt.com.fleetmanagement_v3.types.DeleteFleetRequest, dict]]):
                 The request object. Request object for deleting a Fleet
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -377,16 +399,23 @@ class FleetManagementServiceAsyncClient:
         return response
 
     async def describe_fleet(self,
-            request: Union[service.GetFleetRequest, dict] = None,
+            request: Optional[Union[service.GetFleetRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Fleet:
         r"""Retrieves fleet by Fleet id.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import fleetmanagement_v3
 
             async def sample_describe_fleet():
@@ -404,7 +433,7 @@ class FleetManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.fleetmanagement_v3.types.GetFleetRequest, dict]):
+            request (Optional[Union[oceanbolt.com.fleetmanagement_v3.types.GetFleetRequest, dict]]):
                 The request object. Request object for retrieving a
                 Fleet
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -448,16 +477,23 @@ class FleetManagementServiceAsyncClient:
         return response
 
     async def rename_fleet(self,
-            request: Union[service.RenameFleetRequest, dict] = None,
+            request: Optional[Union[service.RenameFleetRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Fleet:
         r"""Changes the name of a Fleet.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import fleetmanagement_v3
 
             async def sample_rename_fleet():
@@ -475,7 +511,7 @@ class FleetManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.fleetmanagement_v3.types.RenameFleetRequest, dict]):
+            request (Optional[Union[oceanbolt.com.fleetmanagement_v3.types.RenameFleetRequest, dict]]):
                 The request object. Request object for renaming a Fleet
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -518,16 +554,23 @@ class FleetManagementServiceAsyncClient:
         return response
 
     async def share_fleet(self,
-            request: Union[service.ShareFleetRequest, dict] = None,
+            request: Optional[Union[service.ShareFleetRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Fleet:
         r"""Sets the shared status of the Fleet to be shared.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import fleetmanagement_v3
 
             async def sample_share_fleet():
@@ -545,7 +588,7 @@ class FleetManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.fleetmanagement_v3.types.ShareFleetRequest, dict]):
+            request (Optional[Union[oceanbolt.com.fleetmanagement_v3.types.ShareFleetRequest, dict]]):
                 The request object. Request object for sharing a Fleet
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -588,16 +631,23 @@ class FleetManagementServiceAsyncClient:
         return response
 
     async def unshare_fleet(self,
-            request: Union[service.ShareFleetRequest, dict] = None,
+            request: Optional[Union[service.ShareFleetRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Fleet:
         r"""Sets the shared status of the Fleet to be not shared.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import fleetmanagement_v3
 
             async def sample_unshare_fleet():
@@ -615,7 +665,7 @@ class FleetManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.fleetmanagement_v3.types.ShareFleetRequest, dict]):
+            request (Optional[Union[oceanbolt.com.fleetmanagement_v3.types.ShareFleetRequest, dict]]):
                 The request object. Request object for sharing a Fleet
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -658,16 +708,23 @@ class FleetManagementServiceAsyncClient:
         return response
 
     async def list_vessels(self,
-            request: Union[service.ListVesselsRequest, dict] = None,
+            request: Optional[Union[service.ListVesselsRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Vessels:
         r"""Retrieves list of vessels in a Fleet.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import fleetmanagement_v3
 
             async def sample_list_vessels():
@@ -685,7 +742,7 @@ class FleetManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.fleetmanagement_v3.types.ListVesselsRequest, dict]):
+            request (Optional[Union[oceanbolt.com.fleetmanagement_v3.types.ListVesselsRequest, dict]]):
                 The request object. Request object for listing Vessels
                 in a Fleet
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -728,17 +785,103 @@ class FleetManagementServiceAsyncClient:
         # Done; return the response.
         return response
 
-    async def list_vessels_with_status(self,
-            request: Union[service.ListVesselsWithStatusRequest, dict] = None,
+    async def get_vessel(self,
+            request: Optional[Union[service.GetVesselRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+            metadata: Sequence[Tuple[str, str]] = (),
+            ) -> service.Vessel:
+        r"""Retrieves vessel in a Fleet by Fleet id and imo.
+
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from oceanbolt.com import fleetmanagement_v3
+
+            async def sample_get_vessel():
+                # Create a client
+                client = fleetmanagement_v3.FleetManagementServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = fleetmanagement_v3.GetVesselRequest(
+                )
+
+                # Make the request
+                response = await client.get_vessel(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Optional[Union[oceanbolt.com.fleetmanagement_v3.types.GetVesselRequest, dict]]):
+                The request object. Request object for retrieving a
+                Vessel in a Fleet
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            oceanbolt.com.fleetmanagement_v3.types.Vessel:
+                Vessel object
+        """
+        # Create or coerce a protobuf request object.
+        request = service.GetVesselRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.get_vessel,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((
+                ("fleet_id", request.fleet_id),
+                ("imo", request.imo),
+            )),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    async def list_vessels_with_status(self,
+            request: Optional[Union[service.ListVesselsWithStatusRequest, dict]] = None,
+            *,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Vessels:
         r"""Retrieves list of vessels in a Fleet.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import fleetmanagement_v3
 
             async def sample_list_vessels_with_status():
@@ -756,7 +899,7 @@ class FleetManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.fleetmanagement_v3.types.ListVesselsWithStatusRequest, dict]):
+            request (Optional[Union[oceanbolt.com.fleetmanagement_v3.types.ListVesselsWithStatusRequest, dict]]):
                 The request object. Request object for listing Fleet
                 Vessels with status (live state) data and speed events
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -800,10 +943,10 @@ class FleetManagementServiceAsyncClient:
         return response
 
     async def add_vessel(self,
-            request: Union[service.AddVesselRequest, dict] = None,
+            request: Optional[Union[service.AddVesselRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Vessel:
         r"""Adds new vessel to a Fleet. A maximum of 1000 vessels
@@ -811,6 +954,13 @@ class FleetManagementServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import fleetmanagement_v3
 
             async def sample_add_vessel():
@@ -828,7 +978,7 @@ class FleetManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.fleetmanagement_v3.types.AddVesselRequest, dict]):
+            request (Optional[Union[oceanbolt.com.fleetmanagement_v3.types.AddVesselRequest, dict]]):
                 The request object. Request object for adding a Vessel
                 to a Fleet
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -872,16 +1022,23 @@ class FleetManagementServiceAsyncClient:
         return response
 
     async def update_vessel(self,
-            request: Union[service.UpdateVesselRequest, dict] = None,
+            request: Optional[Union[service.UpdateVesselRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Vessel:
         r"""Updates existing metadata for a Vessel.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import fleetmanagement_v3
 
             async def sample_update_vessel():
@@ -899,7 +1056,7 @@ class FleetManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.fleetmanagement_v3.types.UpdateVesselRequest, dict]):
+            request (Optional[Union[oceanbolt.com.fleetmanagement_v3.types.UpdateVesselRequest, dict]]):
                 The request object. Request object for updating a vessel
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -943,16 +1100,23 @@ class FleetManagementServiceAsyncClient:
         return response
 
     async def delete_vessel(self,
-            request: Union[service.DeleteVesselRequest, dict] = None,
+            request: Optional[Union[service.DeleteVesselRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.EmptyResponse:
         r"""Removes a vessel from a Fleet.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import fleetmanagement_v3
 
             async def sample_delete_vessel():
@@ -970,7 +1134,7 @@ class FleetManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.fleetmanagement_v3.types.DeleteVesselRequest, dict]):
+            request (Optional[Union[oceanbolt.com.fleetmanagement_v3.types.DeleteVesselRequest, dict]]):
                 The request object. Request object for deleting a single
                 Vessel from a Fleet
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1015,10 +1179,10 @@ class FleetManagementServiceAsyncClient:
         return response
 
     async def batch_add_vessels(self,
-            request: Union[service.BatchVesselsRequest, dict] = None,
+            request: Optional[Union[service.BatchVesselsRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.EmptyResponse:
         r"""Batch adds vessels into a Fleet. A maximum of 1000
@@ -1026,6 +1190,13 @@ class FleetManagementServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import fleetmanagement_v3
 
             async def sample_batch_add_vessels():
@@ -1043,7 +1214,7 @@ class FleetManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.fleetmanagement_v3.types.BatchVesselsRequest, dict]):
+            request (Optional[Union[oceanbolt.com.fleetmanagement_v3.types.BatchVesselsRequest, dict]]):
                 The request object. Request object for batch adding
                 Vessels to a Fleet
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1087,10 +1258,10 @@ class FleetManagementServiceAsyncClient:
         return response
 
     async def replace_vessels(self,
-            request: Union[service.BatchVesselsRequest, dict] = None,
+            request: Optional[Union[service.BatchVesselsRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.EmptyResponse:
         r"""Replaces the existing vessels in a Fleet with a batch
@@ -1100,6 +1271,13 @@ class FleetManagementServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import fleetmanagement_v3
 
             async def sample_replace_vessels():
@@ -1117,7 +1295,7 @@ class FleetManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.fleetmanagement_v3.types.BatchVesselsRequest, dict]):
+            request (Optional[Union[oceanbolt.com.fleetmanagement_v3.types.BatchVesselsRequest, dict]]):
                 The request object. Request object for batch adding
                 Vessels to a Fleet
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1161,16 +1339,23 @@ class FleetManagementServiceAsyncClient:
         return response
 
     async def drop_vessels(self,
-            request: Union[service.DropVesselsRequest, dict] = None,
+            request: Optional[Union[service.DropVesselsRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.EmptyResponse:
         r"""Drops all the vessels currently in a fleet.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import fleetmanagement_v3
 
             async def sample_drop_vessels():
@@ -1188,7 +1373,7 @@ class FleetManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.fleetmanagement_v3.types.DropVesselsRequest, dict]):
+            request (Optional[Union[oceanbolt.com.fleetmanagement_v3.types.DropVesselsRequest, dict]]):
                 The request object. Request object for dropping Vessels
                 in a Fleet
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1232,10 +1417,10 @@ class FleetManagementServiceAsyncClient:
         return response
 
     async def get_fleet_live_map(self,
-            request: Union[service.GetFleetLiveMapRequest, dict] = None,
+            request: Optional[Union[service.GetFleetLiveMapRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetFleetLiveMapResponse:
         r"""GetFleetLiveMap display static location for vessels
@@ -1243,6 +1428,13 @@ class FleetManagementServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import fleetmanagement_v3
 
             async def sample_get_fleet_live_map():
@@ -1260,7 +1452,7 @@ class FleetManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.fleetmanagement_v3.types.GetFleetLiveMapRequest, dict]):
+            request (Optional[Union[oceanbolt.com.fleetmanagement_v3.types.GetFleetLiveMapRequest, dict]]):
                 The request object. GetFleetLiveMapRequest request
                 object for getting static fleet map
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1298,10 +1490,10 @@ class FleetManagementServiceAsyncClient:
         return response
 
     async def upload_fleet_list(self,
-            request: Union[service.GetFleetListRequest, dict] = None,
+            request: Optional[Union[service.GetFleetListRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.EmptyResponse:
         r"""Uploads file containing fleet data to be parsed into
@@ -1309,6 +1501,13 @@ class FleetManagementServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import fleetmanagement_v3
 
             async def sample_upload_fleet_list():
@@ -1326,7 +1525,7 @@ class FleetManagementServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.fleetmanagement_v3.types.GetFleetListRequest, dict]):
+            request (Optional[Union[oceanbolt.com.fleetmanagement_v3.types.GetFleetListRequest, dict]]):
                 The request object. Request object for parsing a file
                 into a fleet
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1367,14 +1566,7 @@ class FleetManagementServiceAsyncClient:
     async def __aexit__(self, exc_type, exc, tb):
         await self.transport.close()
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "oceanbolt-com-fleetmanagement",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(gapic_version=package_version.__version__)
 
 
 __all__ = (
