@@ -44,14 +44,14 @@ class FleetManagementServiceGrpcTransport(FleetManagementServiceTransport):
 
     def __init__(self, *,
             host: str = 'api.oceanbolt.com',
-            credentials: ga_credentials.Credentials = None,
-            credentials_file: str = None,
-            scopes: Sequence[str] = None,
-            channel: grpc.Channel = None,
-            api_mtls_endpoint: str = None,
-            client_cert_source: Callable[[], Tuple[bytes, bytes]] = None,
-            ssl_channel_credentials: grpc.ChannelCredentials = None,
-            client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
+            credentials: Optional[ga_credentials.Credentials] = None,
+            credentials_file: Optional[str] = None,
+            scopes: Optional[Sequence[str]] = None,
+            channel: Optional[grpc.Channel] = None,
+            api_mtls_endpoint: Optional[str] = None,
+            client_cert_source: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
+            ssl_channel_credentials: Optional[grpc.ChannelCredentials] = None,
+            client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
             quota_project_id: Optional[str] = None,
             client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
             always_use_jwt_access: Optional[bool] = False,
@@ -177,8 +177,8 @@ class FleetManagementServiceGrpcTransport(FleetManagementServiceTransport):
     @classmethod
     def create_channel(cls,
                        host: str = 'api.oceanbolt.com',
-                       credentials: ga_credentials.Credentials = None,
-                       credentials_file: str = None,
+                       credentials: Optional[ga_credentials.Credentials] = None,
+                       credentials_file: Optional[str] = None,
                        scopes: Optional[Sequence[str]] = None,
                        quota_project_id: Optional[str] = None,
                        **kwargs) -> grpc.Channel:
@@ -434,6 +434,32 @@ class FleetManagementServiceGrpcTransport(FleetManagementServiceTransport):
             )
         return self._stubs['list_vessels']
 
+    @property
+    def get_vessel(self) -> Callable[
+            [service.GetVesselRequest],
+            service.Vessel]:
+        r"""Return a callable for the get vessel method over gRPC.
+
+        Retrieves vessel in a Fleet by Fleet id and imo.
+
+        Returns:
+            Callable[[~.GetVesselRequest],
+                    ~.Vessel]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if 'get_vessel' not in self._stubs:
+            self._stubs['get_vessel'] = self.grpc_channel.unary_unary(
+                '/oceanbolt.com.fleetmanagement.v3.FleetManagementService/GetVessel',
+                request_serializer=service.GetVesselRequest.serialize,
+                response_deserializer=service.Vessel.deserialize,
+            )
+        return self._stubs['get_vessel']
+
     @property
     def list_vessels_with_status(self) -> Callable[
             [service.ListVesselsWithStatusRequest],
