@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 from google.protobuf import wrappers_pb2  # type: ignore
@@ -26,6 +28,7 @@ __protobuf__ = proto.module(
         'DeleteFleetRequest',
         'GetFleetRequest',
         'ListVesselsRequest',
+        'GetVesselRequest',
         'ListVesselsWithStatusRequest',
         'ShareFleetRequest',
         'DropVesselsRequest',
@@ -61,11 +64,11 @@ class RenameFleetRequest(proto.Message):
             The new name of the Fleet.
     """
 
-    fleet_id = proto.Field(
+    fleet_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    new_fleet_name = proto.Field(
+    new_fleet_name: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -79,7 +82,7 @@ class CreateFleetRequest(proto.Message):
             The new name of the Fleet.
     """
 
-    fleet_name = proto.Field(
+    fleet_name: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -94,7 +97,7 @@ class DeleteFleetRequest(proto.Message):
             deleted.
     """
 
-    fleet_id = proto.Field(
+    fleet_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -109,7 +112,7 @@ class GetFleetRequest(proto.Message):
             retrieved.
     """
 
-    fleet_id = proto.Field(
+    fleet_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -124,12 +127,33 @@ class ListVesselsRequest(proto.Message):
             vessels to be retrieved.
     """
 
-    fleet_id = proto.Field(
+    fleet_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
 
 
+class GetVesselRequest(proto.Message):
+    r"""Request object for retrieving a Vessel in a Fleet
+
+    Attributes:
+        fleet_id (str):
+            Identifier of the Fleet resource which
+            vessels to be retrieved.
+        imo (int):
+            Imo of the vessel.
+    """
+
+    fleet_id: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    imo: int = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+
+
 class ListVesselsWithStatusRequest(proto.Message):
     r"""Request object for listing Fleet Vessels with status (live
     state) data and speed events
@@ -149,19 +173,19 @@ class ListVesselsWithStatusRequest(proto.Message):
             related events (StoppageEvents etc.)
     """
 
-    fleet_id = proto.Field(
+    fleet_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    last_days = proto.Field(
+    last_days: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    start_date = proto.Field(
+    start_date: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    end_date = proto.Field(
+    end_date: str = proto.Field(
         proto.STRING,
         number=4,
     )
@@ -176,7 +200,7 @@ class ShareFleetRequest(proto.Message):
             shared.
     """
 
-    fleet_id = proto.Field(
+    fleet_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -191,7 +215,7 @@ class DropVesselsRequest(proto.Message):
             vessels should be dropped.
     """
 
-    fleet_id = proto.Field(
+    fleet_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -204,15 +228,15 @@ class BatchVesselsRequest(proto.Message):
         fleet_id (str):
             Identifier of the Fleet resource where
             vessels should be added.
-        vessels (Sequence[oceanbolt.com.fleetmanagement_v3.types.VesselParams]):
+        vessels (MutableSequence[oceanbolt.com.fleetmanagement_v3.types.VesselParams]):
             List of Vessels to be added.
     """
 
-    fleet_id = proto.Field(
+    fleet_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    vessels = proto.RepeatedField(
+    vessels: MutableSequence['VesselParams'] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message='VesselParams',
@@ -223,27 +247,27 @@ class Fleets(proto.Message):
     r"""Response object for listing Fleets
 
     Attributes:
-        fleets (Sequence[oceanbolt.com.fleetmanagement_v3.types.Fleet]):
+        fleets (MutableSequence[oceanbolt.com.fleetmanagement_v3.types.Fleet]):
             List of user defined Fleet resources.
-        organization_fleets (Sequence[oceanbolt.com.fleetmanagement_v3.types.Fleet]):
+        organization_fleets (MutableSequence[oceanbolt.com.fleetmanagement_v3.types.Fleet]):
             List of organizational Fleet resources that
             are shared with the current user.
-        predefined_fleets (Sequence[oceanbolt.com.fleetmanagement_v3.types.Fleet]):
+        predefined_fleets (MutableSequence[oceanbolt.com.fleetmanagement_v3.types.Fleet]):
             List of system level predefined Fleet
             resources.
     """
 
-    fleets = proto.RepeatedField(
+    fleets: MutableSequence['Fleet'] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message='Fleet',
     )
-    organization_fleets = proto.RepeatedField(
+    organization_fleets: MutableSequence['Fleet'] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message='Fleet',
     )
-    predefined_fleets = proto.RepeatedField(
+    predefined_fleets: MutableSequence['Fleet'] = proto.RepeatedField(
         proto.MESSAGE,
         number=3,
         message='Fleet',
@@ -267,44 +291,44 @@ class Fleet(proto.Message):
             The organization that the user belongs to.
         vessels_in_fleet (google.protobuf.wrappers_pb2.Int32Value):
             The number of vessels in the Fleet.
-        vessels (Sequence[oceanbolt.com.fleetmanagement_v3.types.Vessel]):
+        vessels (MutableSequence[oceanbolt.com.fleetmanagement_v3.types.Vessel]):
             List of Vessels in the Fleet.
         shared_with_org (google.protobuf.wrappers_pb2.BoolValue):
             A flag indicating whether this is a shared
             fleet.
     """
 
-    fleet_id = proto.Field(
+    fleet_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    fleet_name = proto.Field(
+    fleet_name: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    platform = proto.Field(
+    platform: str = proto.Field(
         proto.STRING,
         number=8,
     )
-    owner_user_id = proto.Field(
+    owner_user_id: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    organization = proto.Field(
+    organization: str = proto.Field(
         proto.STRING,
         number=6,
     )
-    vessels_in_fleet = proto.Field(
+    vessels_in_fleet: wrappers_pb2.Int32Value = proto.Field(
         proto.MESSAGE,
         number=4,
         message=wrappers_pb2.Int32Value,
     )
-    vessels = proto.RepeatedField(
+    vessels: MutableSequence['Vessel'] = proto.RepeatedField(
         proto.MESSAGE,
         number=5,
         message='Vessel',
     )
-    shared_with_org = proto.Field(
+    shared_with_org: wrappers_pb2.BoolValue = proto.Field(
         proto.MESSAGE,
         number=7,
         message=wrappers_pb2.BoolValue,
@@ -317,7 +341,7 @@ class VesselParams(proto.Message):
     Attributes:
         imo (int):
             Imo of the vessel.
-        metadata (Mapping[str, str]):
+        metadata (MutableMapping[str, str]):
             A dict/map of arbitratry metadata that should
             be added to the vessel in the context of the
             current fleet. This can for example be links to
@@ -330,11 +354,11 @@ class VesselParams(proto.Message):
             owner.
     """
 
-    imo = proto.Field(
+    imo: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    metadata = proto.MapField(
+    metadata: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=3,
@@ -345,14 +369,14 @@ class UpdateVesselParams(proto.Message):
     r"""Parameter object for updating a vessel in a Fleet
 
     Attributes:
-        metadata (Mapping[str, str]):
+        metadata (MutableMapping[str, str]):
             New set of metadata information for a Vessel.
             This will overwrite existing keys/values
             currently stored in the metadata object of the
             Vessel.
     """
 
-    metadata = proto.MapField(
+    metadata: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=3,
@@ -371,11 +395,11 @@ class AddVesselRequest(proto.Message):
             added.
     """
 
-    fleet_id = proto.Field(
+    fleet_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    vessel = proto.Field(
+    vessel: 'VesselParams' = proto.Field(
         proto.MESSAGE,
         number=2,
         message='VesselParams',
@@ -401,20 +425,20 @@ class UpdateVesselRequest(proto.Message):
             error.
     """
 
-    fleet_id = proto.Field(
+    fleet_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    imo = proto.Field(
+    imo: int = proto.Field(
         proto.INT32,
         number=3,
     )
-    vessel = proto.Field(
+    vessel: 'UpdateVesselParams' = proto.Field(
         proto.MESSAGE,
         number=2,
         message='UpdateVesselParams',
     )
-    upsert = proto.Field(
+    upsert: bool = proto.Field(
         proto.BOOL,
         number=4,
     )
@@ -431,11 +455,11 @@ class DeleteVesselRequest(proto.Message):
             IMO number of the Vessel to be deleted.
     """
 
-    fleet_id = proto.Field(
+    fleet_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    imo = proto.Field(
+    imo: int = proto.Field(
         proto.INT32,
         number=2,
     )
@@ -445,18 +469,18 @@ class Vessels(proto.Message):
     r"""List of Vessel objects
 
     Attributes:
-        vessels (Sequence[oceanbolt.com.fleetmanagement_v3.types.Vessel]):
+        vessels (MutableSequence[oceanbolt.com.fleetmanagement_v3.types.Vessel]):
             List of vessels in Fleet.
         vessels_in_fleet (int):
             Number of vessels in a Fleet.
     """
 
-    vessels = proto.RepeatedField(
+    vessels: MutableSequence['Vessel'] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message='Vessel',
     )
-    vessels_in_fleet = proto.Field(
+    vessels_in_fleet: int = proto.Field(
         proto.INT32,
         number=2,
     )
@@ -487,62 +511,62 @@ class Vessel(proto.Message):
             Ex name of the Vessel.
         type_ (str):
             The type of the vessel.
-        metadata (Mapping[str, str]):
+        metadata (MutableMapping[str, str]):
             Metadata object that contains arbitrary data
             fields defined by the user.
         status (oceanbolt.com.fleetmanagement_v3.types.VesselStatus):
             Vessel status (livestate data).
-        stoppage_events (Sequence[oceanbolt.com.fleetmanagement_v3.types.VesselStoppageEvent]):
+        stoppage_events (MutableSequence[oceanbolt.com.fleetmanagement_v3.types.VesselStoppageEvent]):
             Vessel speed events (stoppage data).
     """
 
-    imo = proto.Field(
+    imo: int = proto.Field(
         proto.INT32,
         number=1,
     )
-    dwt = proto.Field(
+    dwt: float = proto.Field(
         proto.DOUBLE,
         number=2,
     )
-    built = proto.Field(
+    built: int = proto.Field(
         proto.INT32,
         number=3,
     )
-    vessel_name = proto.Field(
+    vessel_name: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    segment = proto.Field(
+    segment: str = proto.Field(
         proto.STRING,
         number=5,
     )
-    sub_segment = proto.Field(
+    sub_segment: str = proto.Field(
         proto.STRING,
         number=10,
     )
-    flag_code = proto.Field(
+    flag_code: str = proto.Field(
         proto.STRING,
         number=6,
     )
-    ex_name = proto.Field(
+    ex_name: str = proto.Field(
         proto.STRING,
         number=7,
     )
-    type_ = proto.Field(
+    type_: str = proto.Field(
         proto.STRING,
         number=8,
     )
-    metadata = proto.MapField(
+    metadata: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=9,
     )
-    status = proto.Field(
+    status: 'VesselStatus' = proto.Field(
         proto.MESSAGE,
         number=11,
         message='VesselStatus',
     )
-    stoppage_events = proto.RepeatedField(
+    stoppage_events: MutableSequence['VesselStoppageEvent'] = proto.RepeatedField(
         proto.MESSAGE,
         number=12,
         message='VesselStoppageEvent',
@@ -579,54 +603,54 @@ class VesselStatus(proto.Message):
 
     """
 
-    laden_status = proto.Field(
+    laden_status: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    cargo_status = proto.Field(
+    cargo_status: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    port_call_status = proto.Field(
+    port_call_status: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    related_port_name = proto.Field(
+    related_port_name: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    draught_percentage = proto.Field(
+    draught_percentage: wrappers_pb2.DoubleValue = proto.Field(
         proto.MESSAGE,
         number=5,
         message=wrappers_pb2.DoubleValue,
     )
-    destination = proto.Field(
+    destination: str = proto.Field(
         proto.STRING,
         number=6,
     )
-    destination_port_name = proto.Field(
+    destination_port_name: str = proto.Field(
         proto.STRING,
         number=7,
     )
-    last_position_received_at = proto.Field(
+    last_position_received_at: str = proto.Field(
         proto.STRING,
         number=8,
     )
-    last_static_received_at = proto.Field(
+    last_static_received_at: str = proto.Field(
         proto.STRING,
         number=9,
     )
-    current_speed = proto.Field(
+    current_speed: wrappers_pb2.DoubleValue = proto.Field(
         proto.MESSAGE,
         number=10,
         message=wrappers_pb2.DoubleValue,
     )
-    current_navigational_status = proto.Field(
+    current_navigational_status: wrappers_pb2.Int32Value = proto.Field(
         proto.MESSAGE,
         number=11,
         message=wrappers_pb2.Int32Value,
     )
-    current_commodity_group = proto.Field(
+    current_commodity_group: str = proto.Field(
         proto.STRING,
         number=12,
     )
@@ -660,49 +684,49 @@ class VesselStoppageEvent(proto.Message):
 
     """
 
-    started_at = proto.Field(
+    started_at: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    ended_at = proto.Field(
+    ended_at: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    port_id = proto.Field(
+    port_id: int = proto.Field(
         proto.INT32,
         number=3,
     )
-    port_name = proto.Field(
+    port_name: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    zone_id = proto.Field(
+    zone_id: int = proto.Field(
         proto.INT32,
         number=5,
     )
-    zone_name = proto.Field(
+    zone_name: str = proto.Field(
         proto.STRING,
         number=6,
     )
-    min_speed_observed = proto.Field(
+    min_speed_observed: wrappers_pb2.DoubleValue = proto.Field(
         proto.MESSAGE,
         number=7,
         message=wrappers_pb2.DoubleValue,
     )
-    duration_hours = proto.Field(
+    duration_hours: wrappers_pb2.DoubleValue = proto.Field(
         proto.MESSAGE,
         number=8,
         message=wrappers_pb2.DoubleValue,
     )
-    lat = proto.Field(
+    lat: float = proto.Field(
         proto.DOUBLE,
         number=9,
     )
-    lon = proto.Field(
+    lon: float = proto.Field(
         proto.DOUBLE,
         number=10,
     )
-    classification = proto.Field(
+    classification: str = proto.Field(
         proto.STRING,
         number=11,
     )
@@ -721,11 +745,11 @@ class GetFleetLiveMapRequest(proto.Message):
             outdoors-v11, satellite-v9]
     """
 
-    fleet_id = proto.Field(
+    fleet_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    map_theme = proto.Field(
+    map_theme: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -740,7 +764,7 @@ class GetFleetLiveMapResponse(proto.Message):
             Static fleet map image URL
     """
 
-    map_image = proto.Field(
+    map_image: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -763,23 +787,23 @@ class GetFleetListRequest(proto.Message):
             appended or overwritten
     """
 
-    file_name = proto.Field(
+    file_name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    file = proto.Field(
+    file: bytes = proto.Field(
         proto.BYTES,
         number=2,
     )
-    fleet_id = proto.Field(
+    fleet_id: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    fleet_name = proto.Field(
+    fleet_name: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    overwrite = proto.Field(
+    overwrite: bool = proto.Field(
         proto.BOOL,
         number=5,
     )
