@@ -16,8 +16,9 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, MutableMapping, MutableSequence, Optional, Sequence, Tuple, Type, Union, cast
+
+from oceanbolt.com.polygonmanagement_v3 import gapic_version as package_version
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -53,7 +54,7 @@ class PolygonManagementServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = PolygonManagementServiceGrpcAsyncIOTransport
 
     def get_transport_class(cls,
-            label: str = None,
+            label: Optional[str] = None,
         ) -> Type[PolygonManagementServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -230,7 +231,7 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -277,8 +278,8 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
 
     def __init__(self, *,
             credentials: Optional[ga_credentials.Credentials] = None,
-            transport: Union[str, PolygonManagementServiceTransport, None] = None,
-            client_options: Optional[client_options_lib.ClientOptions] = None,
+            transport: Optional[Union[str, PolygonManagementServiceTransport]] = None,
+            client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
             client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
             ) -> None:
         """Instantiates the polygon management service client.
@@ -292,7 +293,7 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
             transport (Union[str, PolygonManagementServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -322,6 +323,7 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(client_options)
 
@@ -363,16 +365,23 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
             )
 
     def list_layers(self,
-            request: Union[service.ListLayersRequest, dict] = None,
+            request: Optional[Union[service.ListLayersRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListLayersResponse:
         r"""ListLayers lists layers for the current user
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import polygonmanagement_v3
 
             def sample_list_layers():
@@ -427,16 +436,23 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
         return response
 
     def create_layer(self,
-            request: Union[service.CreateLayerRequest, dict] = None,
+            request: Optional[Union[service.CreateLayerRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> resources.Layer:
         r"""CreateLayer creates new layer for the current user
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import polygonmanagement_v3
 
             def sample_create_layer():
@@ -490,16 +506,23 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
         return response
 
     def delete_layer(self,
-            request: Union[service.DeleteLayerRequest, dict] = None,
+            request: Optional[Union[service.DeleteLayerRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> None:
         r"""DeleteLayer deletes layer for the current user
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import polygonmanagement_v3
 
             def sample_delete_layer():
@@ -551,10 +574,10 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
         )
 
     def copy_layer(self,
-            request: Union[service.CopyLayerRequest, dict] = None,
+            request: Optional[Union[service.CopyLayerRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> resources.Layer:
         r"""CopyLayer creates a copy of the existing layer for
@@ -562,6 +585,13 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import polygonmanagement_v3
 
             def sample_copy_layer():
@@ -623,16 +653,23 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
         return response
 
     def describe_layer(self,
-            request: Union[service.GetLayerRequest, dict] = None,
+            request: Optional[Union[service.GetLayerRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> resources.Layer:
         r"""GetLayer gets fleed by layer id for the current user
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import polygonmanagement_v3
 
             def sample_describe_layer():
@@ -694,10 +731,10 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
         return response
 
     def share_layer(self,
-            request: Union[service.ShareLayerRequest, dict] = None,
+            request: Optional[Union[service.ShareLayerRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> resources.Layer:
         r"""Sets the shared status of the layer to be either
@@ -705,6 +742,13 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import polygonmanagement_v3
 
             def sample_share_layer():
@@ -766,10 +810,10 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
         return response
 
     def unshare_layer(self,
-            request: Union[service.ShareLayerRequest, dict] = None,
+            request: Optional[Union[service.ShareLayerRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> resources.Layer:
         r"""Sets the shared status of the layer to be either
@@ -777,6 +821,13 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import polygonmanagement_v3
 
             def sample_unshare_layer():
@@ -838,16 +889,23 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
         return response
 
     def list_polygons(self,
-            request: Union[service.ListPolygonsRequest, dict] = None,
+            request: Optional[Union[service.ListPolygonsRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListPolygonsResponse:
         r"""GetLayerPolygons gets polygons for a given layer
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import polygonmanagement_v3
 
             def sample_list_polygons():
@@ -909,16 +967,23 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
         return response
 
     def add_polygon(self,
-            request: Union[service.AddPolygonRequest, dict] = None,
+            request: Optional[Union[service.AddPolygonRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> resources.Polygon:
         r"""AddPolygon adds new polygon to a layer
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import polygonmanagement_v3
 
             def sample_add_polygon():
@@ -980,16 +1045,23 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
         return response
 
     def update_polygon(self,
-            request: Union[service.UpdatePolygonRequest, dict] = None,
+            request: Optional[Union[service.UpdatePolygonRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> resources.Polygon:
         r"""UpdatePolygon updates a polygon in a given layer
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import polygonmanagement_v3
 
             def sample_update_polygon():
@@ -1052,16 +1124,23 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
         return response
 
     def delete_polygon(self,
-            request: Union[service.DeletePolygonRequest, dict] = None,
+            request: Optional[Union[service.DeletePolygonRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> None:
         r"""DeletePolygon removes a polygon from a given layer
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import polygonmanagement_v3
 
             def sample_delete_polygon():
@@ -1114,16 +1193,23 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
         )
 
     def batch_add_polygons(self,
-            request: Union[service.BatchAddPolygonsRequest, dict] = None,
+            request: Optional[Union[service.BatchAddPolygonsRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.BatchAddPolygonsResponse:
         r"""BatchAddPolygons adds a batch of polygons to a layer
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import polygonmanagement_v3
 
             def sample_batch_add_polygons():
@@ -1185,10 +1271,10 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
         return response
 
     def replace_polygons(self,
-            request: Union[service.ReplacePolygonsRequest, dict] = None,
+            request: Optional[Union[service.ReplacePolygonsRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> None:
         r"""ReplacePolygons replaces all existing polygons in a
@@ -1196,6 +1282,13 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import polygonmanagement_v3
 
             def sample_replace_polygons():
@@ -1247,16 +1340,23 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
         )
 
     def drop_polygons(self,
-            request: Union[service.DropPolygonsRequest, dict] = None,
+            request: Optional[Union[service.DropPolygonsRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> None:
         r"""Drop polygons drops all polygons from a layer
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import polygonmanagement_v3
 
             def sample_drop_polygons():
@@ -1307,7 +1407,7 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
             metadata=metadata,
         )
 
-    def __enter__(self):
+    def __enter__(self) -> "PolygonManagementServiceClient":
         return self
 
     def __exit__(self, type, value, traceback):
@@ -1325,14 +1425,8 @@ class PolygonManagementServiceClient(metaclass=PolygonManagementServiceClientMet
 
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "oceanbolt-com-polygonmanagement",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(gapic_version=package_version.__version__)
 
 
 __all__ = (
