@@ -16,8 +16,9 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, MutableMapping, MutableSequence, Optional, Sequence, Tuple, Type, Union, cast
+
+from oceanbolt.com.portcalls_v3 import gapic_version as package_version
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -52,7 +53,7 @@ class PortCallServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = PortCallServiceGrpcAsyncIOTransport
 
     def get_transport_class(cls,
-            label: str = None,
+            label: Optional[str] = None,
         ) -> Type[PortCallServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -227,7 +228,7 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -274,8 +275,8 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
 
     def __init__(self, *,
             credentials: Optional[ga_credentials.Credentials] = None,
-            transport: Union[str, PortCallServiceTransport, None] = None,
-            client_options: Optional[client_options_lib.ClientOptions] = None,
+            transport: Optional[Union[str, PortCallServiceTransport]] = None,
+            client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
             client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
             ) -> None:
         """Instantiates the port call service client.
@@ -289,7 +290,7 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
             transport (Union[str, PortCallServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -319,6 +320,7 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(client_options)
 
@@ -360,10 +362,10 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
             )
 
     def get_port_calls(self,
-            request: Union[service.GetPortCallsRequest, dict] = None,
+            request: Optional[Union[service.GetPortCallsRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetPortCallsResponse:
         r"""ListPortCalls retrieves lists all port calls for a
@@ -375,6 +377,13 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import portcalls_v3
 
             def sample_get_port_calls():
@@ -429,10 +438,10 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
         return response
 
     def get_port_call_timeseries(self,
-            request: Union[service.GetPortCallsRequest, dict] = None,
+            request: Optional[Union[service.GetPortCallsRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetPortCallTimeseriesResponse:
         r"""GetPortCallTimeseries retrieves aggregated counts for
@@ -440,6 +449,13 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import portcalls_v3
 
             def sample_get_port_call_timeseries():
@@ -496,10 +512,10 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
         return response
 
     def get_port_particulars(self,
-            request: Union[service.GetPortParticularsRequest, dict] = None,
+            request: Optional[Union[service.GetPortParticularsRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetPortParticularsResponse:
         r"""ListPortCalls retrieves lists all port calls for a
@@ -511,6 +527,13 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import portcalls_v3
 
             def sample_get_port_particulars():
@@ -567,10 +590,10 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
         return response
 
     def get_vessels_in_port(self,
-            request: Union[service.GetVesselsInPortRequest, dict] = None,
+            request: Optional[Union[service.GetVesselsInPortRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetVesselsInPortResponse:
         r"""GetVesselsInPort lists all vessels that were within a
@@ -578,6 +601,13 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import portcalls_v3
 
             def sample_get_vessels_in_port():
@@ -630,7 +660,7 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "PortCallServiceClient":
         return self
 
     def __exit__(self, type, value, traceback):
@@ -648,14 +678,8 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
 
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "oceanbolt-com-portcalls",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(gapic_version=package_version.__version__)
 
 
 __all__ = (
