@@ -16,8 +16,9 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, MutableMapping, MutableSequence, Optional, Sequence, Tuple, Type, Union
+
+from oceanbolt.com.vessels_v3 import gapic_version as package_version
 
 from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
@@ -104,7 +105,7 @@ class VesselServiceAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -136,9 +137,9 @@ class VesselServiceAsyncClient:
     get_transport_class = functools.partial(type(VesselServiceClient).get_transport_class, type(VesselServiceClient))
 
     def __init__(self, *,
-            credentials: ga_credentials.Credentials = None,
+            credentials: Optional[ga_credentials.Credentials] = None,
             transport: Union[str, VesselServiceTransport] = "grpc_asyncio",
-            client_options: ClientOptions = None,
+            client_options: Optional[ClientOptions] = None,
             client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
             ) -> None:
         """Instantiates the vessel service client.
@@ -182,10 +183,10 @@ class VesselServiceAsyncClient:
         )
 
     async def list_vessels(self,
-            request: Union[service.ListVesselsRequest, dict] = None,
+            request: Optional[Union[service.ListVesselsRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListVesselsResponse:
         r"""Vessels gets a list of vessels for the given filter
@@ -193,6 +194,13 @@ class VesselServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import vessels_v3
 
             async def sample_list_vessels():
@@ -210,7 +218,7 @@ class VesselServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.vessels_v3.types.ListVesselsRequest, dict]):
+            request (Optional[Union[oceanbolt.com.vessels_v3.types.ListVesselsRequest, dict]]):
                 The request object. Vessels
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -245,16 +253,23 @@ class VesselServiceAsyncClient:
         return response
 
     async def list_stoppage_events(self,
-            request: Union[service.ListStoppageEventsRequest, dict] = None,
+            request: Optional[Union[service.ListStoppageEventsRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListStoppageEventsResponse:
         r"""Fetches ais based stoppage events for a single vessel
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import vessels_v3
 
             async def sample_list_stoppage_events():
@@ -272,7 +287,7 @@ class VesselServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.vessels_v3.types.ListStoppageEventsRequest, dict]):
+            request (Optional[Union[oceanbolt.com.vessels_v3.types.ListStoppageEventsRequest, dict]]):
                 The request object. VesselStoppageEvents
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -307,10 +322,10 @@ class VesselServiceAsyncClient:
         return response
 
     async def list_dark_period_events(self,
-            request: Union[service.ListDarkPeriodEventsRequest, dict] = None,
+            request: Optional[Union[service.ListDarkPeriodEventsRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListDarkPeriodEventsResponse:
         r"""Fetches ais based dark period events for a single
@@ -319,6 +334,13 @@ class VesselServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import vessels_v3
 
             async def sample_list_dark_period_events():
@@ -336,7 +358,7 @@ class VesselServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.vessels_v3.types.ListDarkPeriodEventsRequest, dict]):
+            request (Optional[Union[oceanbolt.com.vessels_v3.types.ListDarkPeriodEventsRequest, dict]]):
                 The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -371,10 +393,10 @@ class VesselServiceAsyncClient:
         return response
 
     async def get_ais_summary(self,
-            request: Union[service.GetAisSummaryRequest, dict] = None,
+            request: Optional[Union[service.GetAisSummaryRequest, dict]] = None,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetAisSummaryResponse:
         r"""Generates summary data regarding AIS received during
@@ -382,6 +404,13 @@ class VesselServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from oceanbolt.com import vessels_v3
 
             async def sample_get_ais_summary():
@@ -399,7 +428,7 @@ class VesselServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[oceanbolt.com.vessels_v3.types.GetAisSummaryRequest, dict]):
+            request (Optional[Union[oceanbolt.com.vessels_v3.types.GetAisSummaryRequest, dict]]):
                 The request object. Request object for
                 GetAisSummaryRequest
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -442,14 +471,7 @@ class VesselServiceAsyncClient:
     async def __aexit__(self, exc_type, exc, tb):
         await self.transport.close()
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "oceanbolt-com-vessels",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(gapic_version=package_version.__version__)
 
 
 __all__ = (
